@@ -10,18 +10,7 @@ from .shared import (
     get_condition,
     add_obj,
 )
-from .route53 import R53RecordSetEFS
-from .securitygroup import SecurityGroup, SecurityGroupIngress
-
-
-class EFSFileSystem(efs.FileSystem):
-    def __init__(self, title, key, **kwargs):
-        super().__init__(title, **kwargs)
-        self.Condition = self.title
-        # by defualt do not encrypt and lower cost performaceMode
-        self.Encrypted = False
-        self.PerformanceMode = "generalPurpose"
-        auto_get_props(self)
+from .ec2 import SecurityGroup, SecurityGroupIngress
 
 
 class EFSMountTarget(efs.MountTarget):
@@ -42,7 +31,6 @@ class EFSMountTarget(efs.MountTarget):
 def EFS_FileStorage(key):
     for n, v in getattr(cfg, key).items():
         resname = f"{key}{n}"  # Ex. EFSFileSystemWordPress
-        recordname = f"RecordSetEFS{n}"
         sgservername = f"SecurityGroupEFSServer{n}"
         sgclientname = f"SecurityGroupEFS{n}"
         sginame = f"SecurityGroupIngressEFS{n}"
@@ -71,20 +59,20 @@ def EFS_FileStorage(key):
         add_obj(get_condition(resname, "equals", "yes", f"{resname}Enabled"))
 
         # resources
-        r_File = EFSFileSystem(resname, key=v)
+        r_File = efs.FileSystem(resname)
+        auto_get_props(r_File, indexname=n)
 
-        if v["R53"]:
-            r_Record = R53RecordSetEFS(recordname, efsname=n)
+        r_SGServer = SecurityGroup(
+            sgservername,
+            Condition=resname,
+            GroupDescription=f"Rule to access EFS FileSystem {n}",
+        )
 
-            add_obj(r_Record)
-
-        r_SGServer = SecurityGroup(sgservername)
-        r_SGServer.Condition = resname
-        r_SGServer.GroupDescription = f"Rule to access EFS FileSystem {n}"
-
-        r_SGClient = SecurityGroup(sgclientname)
-        r_SGClient.Condition = resname
-        r_SGClient.GroupDescription = f"Enable access to EFS FileSystem {n}"
+        r_SGClient = SecurityGroup(
+            sgclientname,
+            Condition=resname,
+            GroupDescription=f"Enable access to EFS FileSystem {n}",
+        )
 
         SGIExtra = {
             "Name": sginame,
@@ -99,14 +87,11 @@ def EFS_FileStorage(key):
         auto_get_props(r_SGI, rootdict=SGIExtra)
 
         # outputs
-        o_File = Output(resname)
-        o_File.Condition = resname
-        o_File.Value = Ref(resname)
-        o_File.Export = Export(resname)
+        o_SGClient = Output(
+            sgclientname,
+            Condition=resname,
+            Value=GetAtt(sgclientname, "GroupId"),
+            Export=Export(sgclientname),
+        )
 
-        o_SGClient = Output(sgclientname)
-        o_SGClient.Condition = resname
-        o_SGClient.Value = GetAtt(sgclientname, "GroupId")
-        o_SGClient.Export = Export(sgclientname)
-
-        add_obj([r_File, r_SGServer, r_SGClient, r_SGI, o_File, o_SGClient])
+        add_obj([r_File, r_SGServer, r_SGClient, r_SGI, o_SGClient])
