@@ -14,8 +14,10 @@ from .shared import (
 
 def EVE_EventRules(key):
     for n, v in getattr(cfg, key).items():
-        resname = f"{key}{n}"
+        if not v.get("IBOX_ENABLED", True):
+            continue
 
+        resname = f"{key}{n}"
         ibox_lo_cfg = v.get("IBOX_LINKED_OBJ", {})
         if isinstance(ibox_lo_cfg, str):
             ibox_lo_cfg = {"Base": ibox_lo_cfg}
@@ -43,11 +45,10 @@ def EVE_EventRules(key):
             if m.startswith("ECSCluster"):
                 # add common "fixed" props
                 auto_get_props(
-                    Target, mapname="EventsRuleTargetECSCluster", indexname=m
-                )
+                    Target, mapname="EventsRuleTargetECSCluster", indexname=m, res_obj_type="AWS::Events::Rule")
 
             # add props found in yaml cfg
-            auto_get_props(Target)
+            auto_get_props(Target, res_obj_type="AWS::Events::Rule")
             Targets.append(Target)
 
         getattr(cfg, resname).update({"IBOX_LINKED_OBJ": ibox_lo_cfg})
