@@ -1,6 +1,5 @@
 import python_minifier
-import troposphere.ssm as ssm
-import troposphere.policies as pol
+from troposphere import policies, ssm
 
 from .common import *
 from .RP import RP_to_cfg
@@ -137,6 +136,8 @@ def add_objoutput(res):
                     obj = iboxprops[f"{mapname}{n}"][0]
                     propname = iboxprops[f"{mapname}{n}"][1]
                     n = getattr(obj, propname)
+                elif n.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
+                    n = eval(n, globals(), {"IBOX_MAPNAME": mapname})
                 join_list.append(n)
 
             res.Value = Join("", join_list)
@@ -514,11 +515,12 @@ def import_lambda(name):
                     code = python_minifier.minify(
                         fdata, rename_globals=True, preserve_globals=["lambda_handler"]
                     )
-            except Exception:
+            except Exception as e:
+                # logging.error(f"Failed minifying: {e}")
                 code = fdata
 
             if len(code) > 4096:
-                logging.warning(f"Inline lambda {lambda_file_trunk} > 4096")
+                logging.warning(f"Inline lambda {lambda_file_trunk} {len(code)} > 4096")
 
             code_lines = code.splitlines(keepends=True)
 
@@ -557,6 +559,7 @@ def auto_get_props(
     remapname="",
     linked_obj_name="",
     linked_obj_index="",
+    res_obj_type=None,
 ):
     # IBOX_RESNAME can be used in yaml and resolved inside get_endvalue
     global IBOX_RESNAME, IBOX_MAPNAME, IBOX_INDEXNAME, IBOX_REMAPNAME, IBOX_PROPNAME
@@ -580,6 +583,8 @@ def auto_get_props(
     # IBOX_OUTPUT
     IBOX_PROPS = {"MAP": {}}
 
+    res_obj_type = getattr(obj, "resource_type", res_obj_type)
+
     def _get_obj(obj, key, obj_propname, mapname):
         props = obj.props
         mapname_obj = f"{mapname}{obj_propname}"
@@ -610,12 +615,55 @@ def auto_get_props(
 
             return obj_tags
 
-        # trick (bad) to detect attributes as CreationPolicy and UpdatePolicy
-        if obj_propname in ["CreationPolicy", "UpdatePolicy"]:
-            prop_class = getattr(pol, obj_propname)
-        else:
-            prop_class = props[obj_propname][0]
+        obj_class = obj.__class__.__name__
+        obj_mod_name = obj.__module__
+        prop_class = props.get(obj_propname, [None])[0]
+        # print(f"TYPE: {res_obj_type}, CLASS: {obj_class}, PROP: {obj_propname}")
 
+        # detect attributes as CreationPolicy not included in obj properties
+        if obj_propname in ["CreationPolicy", "UpdatePolicy"]:
+            prop_class = getattr(policies, obj_propname)
+        elif callable(prop_class) and prop_class.__name__ not in [
+            "validate_variables_name",
+            "policytypes",
+        ]:
+            # prop_class is a method fallback and try to use CloudFormationResourceSpecification
+            if res_obj_type in cfg.TROPO_CLASS_TO_CFM:
+                obj_class = cfg.TROPO_CLASS_TO_CFM[res_obj_type].get(
+                    obj_class, obj_class
+                )
+            try:
+                res_obj_propname = cfg.cfm_res_spec["PropertyTypes"][
+                    f"{res_obj_type}.{obj_class}"
+                ]["Properties"][obj_propname]
+            except Exception:
+                try:
+                    res_obj_propname = cfg.cfm_res_spec["ResourceTypes"][res_obj_type][
+                        "Properties"
+                    ][obj_propname]
+                except Exception:
+                    res_obj_propname = None
+
+            if res_obj_propname:
+                obj_prop_type = res_obj_propname.get("Type")
+                prop_class_type = res_obj_propname.get("ItemType")
+                if not prop_class_type:
+                    prop_class_type = obj_prop_type
+                if not prop_class_type:
+                    prop_class_type = res_obj_propname.get("PrimitiveType")
+
+                # print(f"PROP_CLASS_TYPE: {prop_class_type}")
+                try:
+                    prop_class = getattr(sys.modules[obj_mod_name], prop_class_type)
+                except Exception:
+                    pass
+                else:
+                    if obj_prop_type == "List":
+                        prop_class = [prop_class]
+
+        # print(f"PROP_CLASS: {prop_class}")
+
+        # obj_propname is a class, usually Tropo AWSProperty
         if isinstance(prop_class, type):
             # If object already have that props, object class is
             # the existing already defined object,
@@ -626,7 +674,11 @@ def auto_get_props(
                 prop_obj = prop_class()
 
             if prop_class.__bases__[0].__name__ in ["AWSProperty", "AWSAttribute"]:
-                _populate(prop_obj, key=key[obj_propname], mapname=mapname_obj)
+                _populate(
+                    prop_obj,
+                    key=key[obj_propname],
+                    mapname=mapname_obj,
+                )
                 # Check for incomplete AWSProperty object and set obj to None to skip it
                 try:
                     prop_obj.to_dict()
@@ -643,20 +695,25 @@ def auto_get_props(
 
             return prop_obj
 
-        elif isinstance(prop_class, tuple) and any(
-            n in prop_class for n in [Tags, asgTags]
+        # obj_propname is are Tropo Tags
+        elif (
+            isinstance(prop_class, tuple)
+            and any(n in prop_class for n in [Tags, asgTags])
+        ) or (
+            callable(prop_class) and prop_class.__name__ in ["validate_tags_or_list"]
         ):
             prop_obj = _get_obj_tags()
 
             return prop_obj
 
+        # obj_propname is List of Tropo AWSProperty
         elif (
             isinstance(prop_class, list)
             and isinstance(prop_class[0], type)
             and prop_class[0].__bases__[0].__name__ == "AWSProperty"
         ):
             prop_list = []
-            prop_class = props[obj_propname][0][0]
+            prop_class = prop_class[0]
 
             # for sub obj defined elsewhere
             ibox_sub_obj = key[obj_propname].get("IBOX_SUB_OBJ")
@@ -695,7 +752,7 @@ def auto_get_props(
             if prop_list or ibox_sub_obj:
                 return prop_list
 
-        # Pure dict as KSM Key KeyPolicy
+        # obj_propname is a dict as KSM Key KeyPolicy
         elif (
             isinstance(prop_class, tuple)
             and isinstance(prop_class[0], type)
@@ -832,7 +889,9 @@ def auto_get_props(
             louc_cfg = {}
             for lo_for_index in lo_for_cycle:
                 # need to copy it because it's updated
-                lo_conf = copy.deepcopy(linked_obj_data.get("Conf", {}))
+                lo_conf = copy.deepcopy(
+                    linked_obj_data.get("Conf", {"IBOX_LINKED_OBJ_NAME": IBOX_RESNAME})
+                )
                 lo_conf["IBOX_ENABLED"] = True
                 # for all lo_conf entries, if their value is a string parse it using parse_ibox_key
                 for loc_entry_key, loc_entry_value in lo_conf.items():
@@ -894,7 +953,8 @@ def auto_get_props(
             # but avoid intercepting the "normal" conf that is a dict too (a key named Type must not exist)
             if isinstance(ibox_linked_obj, dict) and "Type" not in ibox_linked_obj:
                 for linked_obj in ibox_linked_obj.values():
-                    _linked_obj(linked_obj)
+                    if linked_obj:
+                        _linked_obj(linked_obj)
             else:
                 _linked_obj(ibox_linked_obj)
 
